@@ -30,8 +30,18 @@ import errno
 import platform
 from types import TracebackType
 from typing import (
-    Union, IO, Any, List, Tuple, Optional, Dict, TypeVar, Type, Set, Iterator,
-    Callable
+    Union,
+    IO,
+    Any,
+    List,
+    Tuple,
+    Optional,
+    Dict,
+    TypeVar,
+    Type,
+    Set,
+    Iterator,
+    Callable,
 )
 
 from mirakuru.base_env import processes_with_env
@@ -43,15 +53,15 @@ from mirakuru.exceptions import (
 )
 from mirakuru.compat import SIGKILL
 
-log = logging.getLogger(__name__)  # pylint: disable=invalid-name
+LOG = logging.getLogger(__name__)
 
-ENV_UUID = 'mirakuru_uuid'
+ENV_UUID = "mirakuru_uuid"
 """
 Name of the environment variable used by mirakuru to mark its subprocesses.
 """
 
 IGNORED_ERROR_CODES = [errno.ESRCH]
-if platform.system() == 'Darwin':
+if platform.system() == "Darwin":
     IGNORED_ERROR_CODES = [errno.ESRCH, errno.EPERM]
 
 # Type variables used for self in functions returning self, so it's correctly
@@ -63,14 +73,12 @@ ExecutorType = TypeVar("ExecutorType", bound="Executor")
 @atexit.register
 def cleanup_subprocesses() -> None:
     """On python exit: find possibly running subprocesses and kill them."""
-    # pylint: disable=redefined-outer-name, reimported, import-outside-toplevel
     # atexit functions tends to loose global imports sometimes so reimport
     # everything what is needed again here:
     import os
     import errno
     from mirakuru.base_env import processes_with_env
     from mirakuru.compat import SIGKILL
-    # pylint: enable=redefined-outer-name, reimported, import-outside-toplevel
 
     pids = processes_with_env(ENV_UUID, str(os.getpid()))
     for pid in pids:
@@ -85,19 +93,19 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
     """Simple subprocess executor with start/stop/kill functionality."""
 
     def __init__(  # pylint:disable=too-many-arguments
-            self,
-            command: Union[str, List[str], Tuple[str, ...]],
-            cwd: Optional[str] = None,
-            shell: bool = False,
-            timeout: Union[int, float] = 3600,
-            sleep: float = 0.1,
-            sig_stop: int = signal.SIGTERM,
-            sig_kill: int = SIGKILL,
-            exp_sig: int = None,
-            envvars: Optional[Dict[str, str]] = None,
-            stdin: Union[None, int, IO[Any]] = subprocess.PIPE,
-            stdout: Union[None, int, IO[Any]] = subprocess.PIPE,
-            stderr: Union[None, int, IO[Any]] = None
+        self,
+        command: Union[str, List[str], Tuple[str, ...]],
+        cwd: Optional[str] = None,
+        shell: bool = False,
+        timeout: Union[int, float] = 3600,
+        sleep: float = 0.1,
+        sig_stop: int = signal.SIGTERM,
+        sig_kill: int = SIGKILL,
+        exp_sig: int = None,
+        envvars: Optional[Dict[str, str]] = None,
+        stdin: Union[None, int, IO[Any]] = subprocess.PIPE,
+        stdout: Union[None, int, IO[Any]] = subprocess.PIPE,
+        stderr: Union[None, int, IO[Any]] = None,
     ) -> None:
         """
         Initialize executor.
@@ -133,7 +141,7 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
 
         """
         if isinstance(command, (list, tuple)):
-            self.command = ' '.join((shlex.quote(c) for c in command))
+            self.command = " ".join((shlex.quote(c) for c in command))
             """Command that the executor runs."""
             self.command_parts = command
         else:
@@ -142,7 +150,7 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
 
         self._cwd = cwd
         self._shell = True
-        if platform.system() != 'Windows':
+        if platform.system() != "Windows":
             self._shell = shell
 
         self._timeout = timeout
@@ -160,7 +168,7 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         self.process: Optional[subprocess.Popen] = None
         """A :class:`subprocess.Popen` instance once process is started."""
 
-        self._uuid = f'{os.getpid()}:{uuid.uuid4()}'
+        self._uuid = f"{os.getpid()}:{uuid.uuid4()}"
 
     def __enter__(self: SimpleExecutorType) -> SimpleExecutorType:
         """
@@ -171,10 +179,12 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         """
         return self.start()
 
-    def __exit__(self,
-                 exc_type: Optional[Type[BaseException]],
-                 exc_value: Optional[BaseException],
-                 traceback: Optional[TracebackType]) -> None:
+    def __exit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_value: Optional[BaseException],
+        traceback: Optional[TracebackType],
+    ) -> None:
         """Exit context manager stopping the subprocess."""
         self.stop()
 
@@ -182,10 +192,11 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         """
         Check if executor is running.
 
-        :returns: SimpleExecutorTyperue if process is running, False otherwise
+        :returns: True if process is running, False otherwise
         :rtype: bool
         """
         if self.process is None:
+            LOG.debug("There is no process running!")
             return False
         return self.process.poll() is None
 
@@ -204,14 +215,14 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         kwargs: Dict[str, Any] = {}
 
         if self._stdin:
-            kwargs['stdin'] = self._stdin
+            kwargs["stdin"] = self._stdin
         if self._stdout:
-            kwargs['stdout'] = self._stdout
+            kwargs["stdout"] = self._stdout
         if self._stderr:
-            kwargs['stderr'] = self._stderr
-        kwargs['universal_newlines'] = True
+            kwargs["stderr"] = self._stderr
+        kwargs["universal_newlines"] = True
 
-        kwargs['shell'] = self._shell
+        kwargs["shell"] = self._shell
 
         env = os.environ.copy()
         env.update(self._envvars)
@@ -226,11 +237,11 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         # There may be a situation when some subprocess will abandon
         # original envs from parents and then it won't be later found.
         env[ENV_UUID] = self._uuid
-        kwargs['env'] = env
+        kwargs["env"] = env
 
-        kwargs['cwd'] = self._cwd
-        if platform.system() != 'Windows':
-            kwargs['preexec_fn'] = os.setsid
+        kwargs["cwd"] = self._cwd
+        if platform.system() != "Windows":
+            kwargs["preexec_fn"] = os.setsid
 
         return kwargs
 
@@ -247,11 +258,8 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
             command: Union[str, List[str], Tuple[str, ...]] = self.command
             if not self._shell:
                 command = self.command_parts
-
-            self.process = subprocess.Popen(
-                command,
-                **self._popen_kwargs
-            )
+            LOG.debug("Starting process: %s", command)
+            self.process = subprocess.Popen(command, **self._popen_kwargs)
 
         self._set_timeout()
         return self
@@ -287,7 +295,7 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         """
         pids = processes_with_env(ENV_UUID, self._uuid)
         for pid in pids:
-            log.debug("Killing process %d ...", pid)
+            LOG.debug("Killing process %d ...", pid)
             try:
                 os.kill(pid, sig)
             except OSError as err:
@@ -296,13 +304,11 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
                     pass
                 else:
                     raise
-            log.debug("Killed process %d.", pid)
+            LOG.debug("Killed process %d.", pid)
         return pids
 
     def stop(
-            self: SimpleExecutorType,
-            sig: int = None,
-            exp_sig: int = None
+        self: SimpleExecutorType, sig: int = None, exp_sig: int = None
     ) -> SimpleExecutorType:
         """
         Stop process running.
@@ -360,7 +366,6 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         # Did the process shut down cleanly? A an exit code of `-sig` means
         # that it has terminated due to signal `sig`, which is intended. So
         # don't treat that as an error.
-        # pylint: disable=invalid-unary-operand-type
         expected_exit_code = -sig
         if exp_sig is not None:
             expected_exit_code = -exp_sig
@@ -386,9 +391,8 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
             self.start()
 
     def kill(
-            self: SimpleExecutorType,
-            wait: bool = True,
-            sig: Optional[int] = None) -> SimpleExecutorType:
+        self: SimpleExecutorType, wait: bool = True, sig: Optional[int] = None
+    ) -> SimpleExecutorType:
         """
         Kill the process if running.
 
@@ -423,8 +427,8 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         return None  # pragma: no cover
 
     def wait_for(
-            self: SimpleExecutorType,
-            wait_for: Callable[[], bool]) -> SimpleExecutorType:
+        self: SimpleExecutorType, wait_for: Callable[[], bool]
+    ) -> SimpleExecutorType:
         """
         Wait for callback to return True.
 
@@ -465,8 +469,10 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
                 self.kill()
         except Exception:  # pragma: no cover
             print("*" * 80)
-            print("Exception while deleting Executor. '"
-                  "It is strongly suggested that you use")
+            print(
+                "Exception while deleting Executor. '"
+                "It is strongly suggested that you use"
+            )
             print("it as a context manager instead.")
             print("*" * 80)
             raise
@@ -475,7 +481,7 @@ class SimpleExecutor:  # pylint:disable=too-many-instance-attributes
         """Return unambiguous executor representation."""
         command = self.command
         if len(command) > 10:
-            command = command[:10] + '...'
+            command = command[:10] + "..."
         module = self.__class__.__module__
         executor = self.__class__.__name__
         return f'<{module}.{executor}: "{command}" {hex(id(self))}>'
@@ -513,7 +519,7 @@ class Executor(SimpleExecutor):
             # Some other executor (or process) is running with same config:
             raise AlreadyRunning(self)
 
-        super(Executor, self).start()
+        super().start()
 
         self.wait_for(self.check_subprocess)
         return self
