@@ -16,16 +16,16 @@ class ExecutorError(Exception):
         :param mirakuru.base.SimpleExecutor executor: for which exception
             occurred
         """
-        super(ExecutorError, self).__init__(self)
+        super().__init__(self)
         self.executor = executor
 
 
 class TimeoutExpired(ExecutorError):
     """Is raised when the timeout expires while starting an executor."""
 
-    def __init__(self,
-                 executor: "SimpleExecutor",
-                 timeout: Union[int, float]) -> None:
+    def __init__(
+        self, executor: "SimpleExecutor", timeout: Union[int, float]
+    ) -> None:
         """
         Exception initialization with an extra ``timeout`` argument.
 
@@ -33,7 +33,7 @@ class TimeoutExpired(ExecutorError):
             occurred
         :param int timeout: timeout for which exception occurred
         """
-        super(TimeoutExpired, self).__init__(executor)
+        super().__init__(executor)
         self.timeout = timeout
 
     def __str__(self) -> str:
@@ -44,7 +44,7 @@ class TimeoutExpired(ExecutorError):
         :rtype: str
         """
         return (
-            f'Executor {self.executor} timed out after {self.timeout} seconds'
+            f"Executor {self.executor} timed out after {self.timeout} seconds"
         )
 
 
@@ -63,13 +63,18 @@ class AlreadyRunning(ExecutorError):
         :returns: string representation
         :rtype: str
         """
-        port = getattr(self.executor, 'port')
-        return (f"Executor {self.executor} seems to be already running. "
-                f"It looks like the previous executor process hasn't been "
-                f"terminated or killed."
-                + ("" if port is None else
-                   f" Also there might be some completely "
-                   f"different service listening on {port} port."))
+        port = getattr(self.executor, "port")
+        return (
+            f"Executor {self.executor} seems to be already running. "
+            f"It looks like the previous executor process hasn't been "
+            f"terminated or killed."
+            + (
+                ""
+                if port is None
+                else f" Also there might be some completely "
+                f"different service listening on {port} port."
+            )
+        )
 
 
 class ProcessExitedWithError(ExecutorError):
@@ -89,7 +94,7 @@ class ProcessExitedWithError(ExecutorError):
             occurred
         :param int exit_code: code the subprocess exited with
         """
-        super(ProcessExitedWithError, self).__init__(executor)
+        super().__init__(executor)
         self.exit_code = exit_code
 
     def __str__(self) -> str:
@@ -99,8 +104,10 @@ class ProcessExitedWithError(ExecutorError):
         :returns: string representation
         :rtype: str
         """
-        return (f"The process invoked by the {self.executor} executor has "
-                f"exited with a non-zero code: {self.exit_code}.")
+        return (
+            f"The process invoked by the {self.executor} executor has "
+            f"exited with a non-zero code: {self.exit_code}."
+        )
 
 
 class ProcessFinishedWithError(ProcessExitedWithError):
